@@ -3,7 +3,10 @@
 #' Generate a lexical dispersion plot of terms.
 #' 
 #' @param text.var The text variable.
-#' @param match.terms  A vector of quoted terms.
+#' @param match.terms  A vector of quoted terms or a named list of quoted terms.  
+#' If the latter terms will be combined into a single unified theme named 
+#' according to the list names.  Note that terms within the vectors of the list 
+#' cannot be duplicated.
 #' @param grouping.var The grouping variables.  Default \code{NULL} generates 
 #' one word list for all text.  Also takes a single grouping variable or a list 
 #' of 1 or more grouping variables.
@@ -69,7 +72,7 @@
 #'     bg.color = "black", grouping.var = list(fam.aff, sex), 
 #'     color = "yellow", total.color = "white", horiz.color="grey20"))
 #'     
-#' ## Use word list
+#' ## Use `word_list`
 #' ## Presidential debates by all
 #' wrds <- word_list(pres_debates2012$dialogue, stopwords = Top200Words)
 #' wrds2 <- spaste(wrds[["rfswl"]][["all"]][, "WORD"])
@@ -88,6 +91,33 @@
 #'     bg.color = "white", grouping.var = person, rm.vars = time,
 #'     color = "black", horiz.color="grey80"))
 #' 
+#' wordlist2 <- c(" i'd ", " i'll ", " i'm ", " i've ", " i ", 
+#'     " we'd ", " we'll ", " we're ", " we've ", " we ", 
+#'     " you'd ",  " you'll ", " you're ", " you've ", " you ", " your ",
+#'     " he'd ", " he'll ", " he's ", " he ")
+#' 
+#' with(dat, dispersion_plot(dialogue, wordlist2, 
+#'     bg.color = "black", grouping.var = person, rm.vars = time,
+#'     color = "yellow", total.color = NULL, horiz.color="grey20"))
+#'    
+#' with(dat, dispersion_plot(dialogue, wordlist2, 
+#'     bg.color = "black", grouping.var = person, rm.vars = time,
+#'     color = "red", total.color = "white", horiz.color="grey20"))
+#' 
+#' ## `match.terms` as a named list        
+#' wordlist3 <- list(
+#'     I = c(" i'd ", " i'll ", " i'm ", " i've ", " i "),
+#'     we = c(" we'd ", " we'll ", " we're ", " we've ", " we "),
+#'     you = c(" you'd ",  " you'll ", " you're ", " you've ", " you ", " your "),
+#'     he = c(" he'd ", " he'll ", " he's ", " he ")
+#' )
+#' 
+#' with(dat, dispersion_plot(dialogue, wordlist3,
+#'     bg.color = "grey60", grouping.var = person, rm.vars = time,
+#'     color = "blue", total.color = "grey40", horiz.color="grey20"))
+#' 
+#' colsplit2df(scores(with(dat, termco(dialogue, list(time, person), wordlist3))))
+#' 
 #' ## Extras:
 #' ## Reverse facets
 #' 
@@ -108,6 +138,14 @@ dispersion_plot <- function(text.var, match.terms, grouping.var = NULL,
     size = 4, plot = TRUE, char2space = "~~", apostrophe.remove = FALSE, 
     scales="free", space="free", ...) {
 
+    match.list <- NULL
+    if (is.list_o_vectors(match.terms)) {
+        match.terms <- list_namer(match.terms)
+        match.list <- match.terms
+        match.terms <- unlist(match.terms)
+        if (any(duplicated(match.terms))) stop("`match.terms` cannot contain duplicates")
+    }
+
     word.num <- NULL
     GV <- ifelse(!is.null(grouping.var), TRUE, FALSE)
 
@@ -164,7 +202,8 @@ dispersion_plot <- function(text.var, match.terms, grouping.var = NULL,
     }
 
     DF[, "time"] <- factor(DF[, "time"])
-
+    DF <- DF[!is.na(DF[["text.var"]]), ]
+    
     ## split DF into a list by rm.vars
     LDF <- split(DF, DF[, "time"])
 
@@ -199,8 +238,7 @@ dispersion_plot <- function(text.var, match.terms, grouping.var = NULL,
 
     ## used for color fill when total.color != NULL
     dat2[, "summary"] <- rep("sub", nrow(dat2))
-
-
+    
     ## Add totals if total.color != NULL
     if (!is.null(total.color) && GV) {
         dat2b <- dat2
@@ -214,6 +252,18 @@ dispersion_plot <- function(text.var, match.terms, grouping.var = NULL,
         cols <- color
     }
 
+    if(!is.null(match.list)) {
+
+        word2 <- rep(NA, nrow(dat2))
+        for (i in seq_along(match.list)) {
+            word2[dat2[["text"]] %in% match.list[[i]]] <- paste(" ", names(match.list)[i])
+        }
+        dat2[["word"]] <- factor(word2, levels=paste(" ", names(match.list)))
+    }
+
+    ## remove NA values
+    dat2 <- dat2[!is.na(dat2[["word"]]), ]
+
     the_plot <- ggplot(data = dat2, aes(x = word.num, y = grouping)) + 
         geom_point(aes(position="dodge", color = summary), 
             shape = symbol, size = size) + 
@@ -225,7 +275,6 @@ dispersion_plot <- function(text.var, match.terms, grouping.var = NULL,
             panel.grid.major.y = element_line(color = horiz.color),
             strip.text.y = element_text(angle=0, hjust = 0), 
             strip.background = element_blank()) +
-        scale_x_continuous(expand = c(0, 0)) + 
         ylab(ylab) + xlab(xlab) + ggtitle(title) + 
         scale_colour_manual(values = cols, guide=FALSE)
 
@@ -243,6 +292,7 @@ dispersion_plot <- function(text.var, match.terms, grouping.var = NULL,
     if (plot) {
         print(the_plot)
     }
+    attributes(the_plot)[["qdap_data"]] <- dat2
     invisible(the_plot)
 }
 
