@@ -47,7 +47,6 @@
 #' \code{\link[qdap]{TOT}} 
 #' @keywords sentence, split, turn-of-talk
 #' @export
-#' @importFrom dplyr tbl_df
 #' @examples
 #' \dontrun{
 #' ## `sentSplit` EXAMPLE:
@@ -132,7 +131,6 @@ function(dataframe, text.var, rm.var = NULL, endmarks = c("?", ".", "!", "|"),
     if (!is.null(rm.var)) {
         rm.var <- paste0("rmvars_", paste(rm.var, collapse = ":"))
     } 
-    output <- tbl_df(output)
     class(output) <- unique(c("sent_split", "qdap_df", 
         paste0("sent_split_text_var:", text.var), rm.var, class(output)))
     attributes(output)[["text.var"]] <- text.var
